@@ -48,10 +48,6 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Change column dtype'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'change_column_dtype_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -72,7 +68,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         **params
     ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # Create the post state
-        post_state = copy(prev_state)
+        post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
 
         column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
         
