@@ -1,14 +1,14 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 import csv
 import json
 from os.path import normpath, basename
 import os
 from copy import copy
+from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 import chardet
 import pandas as pd
@@ -37,10 +37,6 @@ class SimpleImportStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Imported CSV Files'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'simple_import_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -61,16 +57,19 @@ class SimpleImportStepPerformer(StepPerformer):
                 raise make_is_directory_error(file_name)
 
         # Create a new step
-        post_state = copy(prev_state)
+        post_state = prev_state.copy()
 
         file_delimeters = []
         file_encodings = []
 
         just_final_file_names = [basename(normpath(file_name)) for file_name in file_names]
 
+        pandas_processing_time = 0.0
         for file_name, df_name in zip(file_names, get_valid_dataframe_names(post_state.df_names, just_final_file_names)):
-
+            
+            partial_pandas_start_time = perf_counter()
             df, delimeter, encoding = read_csv_get_delimeter_and_encoding(file_name)
+            pandas_processing_time += (perf_counter() - partial_pandas_start_time)
 
             # Save the delimeter and encodings for transpiling
             file_delimeters.append(delimeter)
@@ -87,7 +86,8 @@ class SimpleImportStepPerformer(StepPerformer):
         # and also save the seperator that we used for each file
         return post_state, {
             'file_delimeters': file_delimeters,
-            'file_encodings': file_encodings
+            'file_encodings': file_encodings,
+            'pandas_processing_time': pandas_processing_time
         }
 
     @classmethod
